@@ -150,14 +150,11 @@ describe("Babel", function () {
       "  3.1415926535897932m,",
       "  100.000m,",
       "  123456.789m",
-      ");"
+      ");",
     ]);
 
     // V8IntrinsicIdentifier
-    check([
-      "%DebugPrint('hello');",
-      "%DebugPrint(%StringParseInt('42', 10));",
-    ]);
+    check(["%DebugPrint('hello');", "%DebugPrint(%StringParseInt('42', 10));"]);
   });
 
   it("babel 6: should not wrap IIFE when reusing nodes", function () {
