@@ -660,6 +660,16 @@ describe("printer", function () {
     );
   });
 
+  it("pretty-prints U+2028 and U+2029 as Unicode escapes", function () {
+    const ast = parse('"\\u2028";');
+    const printer = new Printer();
+    assert.strictEqual(printer.printGenerically(ast).code, '"\\u2028";');
+
+    const ast2 = parse('"\\u2029";');
+    const printer2 = new Printer();
+    assert.strictEqual(printer2.printGenerically(ast2).code, '"\\u2029";');
+  });
+
   it("should print block comments at head of class once", function () {
     // Given.
     const ast = parse(
@@ -1138,6 +1148,31 @@ describe("printer", function () {
     assert.strictEqual(pretty, code);
   });
 
+  it("adds parenthesis around nullish expression, when nullish expression is BinaryExpression's child", function () {
+    const code = "let a = (c?.b ?? 1) + 1;";
+
+    const b = recast.types.builders;
+
+    const ast = b.variableDeclaration("let", [
+      b.variableDeclarator(
+        b.identifier("a"),
+        b.binaryExpression(
+          "+",
+          b.logicalExpression(
+            "??",
+            b.optionalMemberExpression(b.identifier("c"), b.identifier("b")),
+            b.numericLiteral(1),
+          ),
+          b.numericLiteral(1),
+        ),
+      ),
+    ]);
+
+    const printer = new Printer();
+    const pretty = printer.printGenerically(ast).code;
+    assert.strictEqual(pretty, code);
+  });
+
   it("prints class property initializers with type annotations correctly", function () {
     const code = ["class A {", "  foo = (a: b): void => {};", "}"].join(eol);
 
@@ -1190,6 +1225,33 @@ describe("printer", function () {
     assert.strictEqual(pretty, code);
   });
 
+  it("prints 'definite' ClassProperty correctly", function () {
+    const code = ["class A {", "  foo!: string;", "}"].join(eol);
+
+    const ast = b.program([
+      b.classDeclaration(
+        b.identifier("A"),
+        b.classBody([
+          Object.assign(
+            b.classProperty(
+              b.identifier("foo"),
+              null,
+              b.typeAnnotation(b.stringTypeAnnotation()),
+            ),
+            { definite: true },
+          ),
+        ]),
+      ),
+    ]);
+
+    const printer = new Printer({
+      tabWidth: 2,
+    });
+
+    const pretty = printer.printGenerically(ast).code;
+    assert.strictEqual(pretty, code);
+  });
+
   it("prints static ClassProperty correctly", function () {
     const code = ["class A {", "  static foo = Bar;", "}"].join(eol);
 
@@ -1671,12 +1733,8 @@ describe("printer", function () {
 
   it("prints chained expression elements", function () {
     const node = b.chainExpression(
-      b.memberExpression(
-        b.identifier("foo"),
-        b.identifier("bar"),
-        false
-      ),
-    )
+      b.memberExpression(b.identifier("foo"), b.identifier("bar"), false),
+    );
 
     assert.strictEqual(recast.print(node).code, "foo.bar");
   });
@@ -1687,9 +1745,9 @@ describe("printer", function () {
         b.identifier("foo"),
         b.identifier("bar"),
         false,
-        true
+        true,
       ),
-    )
+    );
 
     assert.strictEqual(recast.print(node).code, "foo?.bar");
   });
@@ -2192,23 +2250,29 @@ describe("printer", function () {
     });
 
     const emptyBlockReprinted = printer.print(ast).code;
-    assert.strictEqual(emptyBlockReprinted, [
-      "class A {",
-      "  static a = 1;",
-      "  static #b = 2;",
-      "", // Empty line preserved because of conservative printer.print reprinting.
-      "  static {}",
-      "}",
-    ].join(eol));
+    assert.strictEqual(
+      emptyBlockReprinted,
+      [
+        "class A {",
+        "  static a = 1;",
+        "  static #b = 2;",
+        "", // Empty line preserved because of conservative printer.print reprinting.
+        "  static {}",
+        "}",
+      ].join(eol),
+    );
 
     const emptyBlockPrettyPrinted = printer.printGenerically(ast).code;
-    assert.strictEqual(emptyBlockPrettyPrinted, [
-      "class A {",
-      "  static a = 1;",
-      "  static #b = 2;",
-      "  static {}",
-      "}",
-    ].join(eol));
+    assert.strictEqual(
+      emptyBlockPrettyPrinted,
+      [
+        "class A {",
+        "  static a = 1;",
+        "  static #b = 2;",
+        "  static {}",
+        "}",
+      ].join(eol),
+    );
   });
 
   it("can pretty-print ImportAttribute syntax", function () {
@@ -2223,10 +2287,10 @@ describe("printer", function () {
       'import * as noAssertions from "./module";',
       'import * as emptyAssert from "./module";',
       'import json from "./module" assert { type: "json" };',
-      '',
+      "",
       'import * as ns from "./module" assert {',
       '  type: "reallyLongStringLiteralThatShouldTriggerReflowOntoMultipleLines"',
-      '};',
+      "};",
     ].join(eol);
 
     const printer = new Printer({
@@ -2254,12 +2318,15 @@ describe("printer", function () {
     });
 
     const reprinted = printer.print(ast).code;
-    assert.strictEqual(reprinted, [
-      'import * as noAssertions from "./module";',
-      'import * as emptyAssert from "./module" assert {};',
-      'import json from "./module" assert { type: "json" };',
-      'import * as ns from "./module" assert { type: "shorter" }',
-    ].join(eol));
+    assert.strictEqual(
+      reprinted,
+      [
+        'import * as noAssertions from "./module";',
+        'import * as emptyAssert from "./module" assert {};',
+        'import json from "./module" assert { type: "json" };',
+        'import * as ns from "./module" assert { type: "shorter" }',
+      ].join(eol),
+    );
   });
 
   it("can pretty-print RecordExpression syntax", function () {
@@ -2316,8 +2383,8 @@ describe("printer", function () {
   it("can pretty-print ModuleExpression syntax", function () {
     const code = [
       'import { log } from "logger";',
-      'export const url = import.meta.url;',
-      'log(url);',
+      "export const url = import.meta.url;",
+      "log(url);",
     ].join(eol);
 
     const ast = parse(code, {
@@ -2332,13 +2399,12 @@ describe("printer", function () {
     const pretty = printer.printGenerically(ast).code;
     assert.strictEqual(pretty, code);
 
-    const reprinted = printer.print(
-      b.moduleExpression(ast.program)
-    ).code;
-    assert.strictEqual(reprinted, [
-      "module {",
-      ...code.split(eol).map(line => "  " + line),
-      "}",
-    ].join(eol));
+    const reprinted = printer.print(b.moduleExpression(ast.program)).code;
+    assert.strictEqual(
+      reprinted,
+      ["module {", ...code.split(eol).map((line) => "  " + line), "}"].join(
+        eol,
+      ),
+    );
   });
 });
